@@ -3,13 +3,13 @@
 from decimal import Decimal
 
 from trytond import backend
-from trytond.pool import PoolMeta, Pool
-from trytond.model import ModelSQL, fields
-from trytond.pyson import Eval
 from trytond.config import config
-from trytond.tools.multivalue import migrate_property
+from trytond.model import ModelSQL, fields
 from trytond.modules.company.model import (
     CompanyMultiValueMixin, CompanyValueMixin)
+from trytond.pool import Pool, PoolMeta
+from trytond.pyson import Eval
+from trytond.tools.multivalue import migrate_property
 
 STATES = {
     'readonly': ~Eval('active', True),
